==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/SecretsManagerAccessTokenConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SecretsManagerAccessTokenConfiguration(
    headerName: Option[__string] = None,
    secretArn: Option[__string] = None,
    secretStringKey: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration = {
    import SecretsManagerAccessTokenConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
      .builder()
      .optionallyWith(
        headerName.map(value => __string.unwrap(value): java.lang.String)
      )(_.headerName)
      .optionallyWith(
        secretArn.map(value => __string.unwrap(value): java.lang.String)
      )(_.secretArn)
      .optionallyWith(
        secretStringKey.map(value => __string.unwrap(value): java.lang.String)
      )(_.secretStringKey)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly =
    zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration
      .wrap(buildAwsValue())
}
object SecretsManagerAccessTokenConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration =
      zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration(
        headerName.map(value => value),
        secretArn.map(value => value),
        secretStringKey.map(value => value)
      )
    def headerName: Option[__string]
    def secretArn: Option[__string]
    def secretStringKey: Option[__string]
    def getHeaderName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("headerName", headerName)
    def getSecretArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getSecretStringKey: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("secretStringKey", secretStringKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ) extends zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly {
    override val headerName: Option[__string] = scala
      .Option(impl.headerName())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
    override val secretArn: Option[__string] = scala
      .Option(impl.secretArn())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
    override val secretStringKey: Option[__string] = scala
      .Option(impl.secretStringKey())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ): zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/SecretsManagerAccessTokenConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SecretsManagerAccessTokenConfiguration(
    headerName: Option[__string] = None,
    secretArn: Option[__string] = None,
    secretStringKey: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration = {
    import SecretsManagerAccessTokenConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
      .builder()
      .optionallyWith(headerName.map(value => value: java.lang.String))(
        _.headerName
      )
      .optionallyWith(secretArn.map(value => value: java.lang.String))(
        _.secretArn
      )
      .optionallyWith(secretStringKey.map(value => value: java.lang.String))(
        _.secretStringKey
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly =
    zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration
      .wrap(buildAwsValue())
}
object SecretsManagerAccessTokenConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration =
      zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration(
        headerName.map(value => value),
        secretArn.map(value => value),
        secretStringKey.map(value => value)
      )
    def headerName: Option[__string]
    def secretArn: Option[__string]
    def secretStringKey: Option[__string]
    def getHeaderName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("headerName", headerName)
    def getSecretArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getSecretStringKey: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("secretStringKey", secretStringKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ) extends zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly {
    override val headerName: Option[__string] =
      scala.Option(impl.headerName()).map(value => value: __string)
    override val secretArn: Option[__string] =
      scala.Option(impl.secretArn()).map(value => value: __string)
    override val secretStringKey: Option[__string] =
      scala.Option(impl.secretStringKey()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.SecretsManagerAccessTokenConfiguration
  ): zio.aws.mediatailor.model.SecretsManagerAccessTokenConfiguration.ReadOnly =
    new Wrapper(impl)
}
